# The Data Manager Package

The ``dman`` package is intended for enabling easy reproducibility of numerical experiments. Data is stored in a human-readable fashion (whenever possible).

[Documentation](https://petercoppens.github.io/dman/docs/index.html) is provided in Sphinx. 
A good place to start is the [Getting Started](https://petercoppens.github.io/dman/docs/usage/common.html) page.

Documented [Examples](./examples/) are also provided. Especially check out those 
in [Patterns](./examples/patterns/) for common use-cases.
